@@ -1,4 +1,4 @@
-/* Copyright (C) 2009-2019 Greenbone Networks GmbH
+/* Copyright (C) 2009-2021 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -54,6 +54,11 @@ nvtpref_id (const nvtpref_t *);
  */
 typedef struct vtref vtref_t;
 
+/**
+ * @brief The structure for a severity of a VT.
+ */
+typedef struct vtseverity vtseverity_t;
+
 /**
  * @brief The structure of a information record that corresponds to a NVT.
  */
@@ -70,6 +75,21 @@ vtref_id (const vtref_t *);
 const gchar *
 vtref_text (const vtref_t *);
 
+vtseverity_t *
+vtseverity_new (const gchar *, const gchar *, int, double, const gchar *);
+void
+vtseverity_free (vtseverity_t *);
+const gchar *
+vtseverity_type (const vtseverity_t *);
+const gchar *
+vtseverity_origin (const vtseverity_t *);
+const gchar *
+vtseverity_value (const vtseverity_t *);
+int
+vtseverity_date (const vtseverity_t *);
+double
+vtseverity_score (const vtseverity_t *);
+
 int
 nvti_add_vtref (nvti_t *, vtref_t *);
 guint
@@ -77,6 +97,15 @@ nvti_vtref_len (const nvti_t *);
 vtref_t *
 nvti_vtref (const nvti_t *, guint);
 
+int
+nvti_add_vtseverity (nvti_t *, vtseverity_t *);
+guint
+nvti_vtseverities_len (const nvti_t *);
+vtseverity_t *
+nvti_vtseverity (const nvti_t *, guint);
+double
+nvti_severity_score (const nvti_t *);
+
 nvti_t *
 nvti_new (void);
 void
