@@ -414,7 +414,8 @@ redis_memory_purge (kb_t kb)
  * @param[in] kb  Reference to a kb_t to initialize.
  * @param[in] kb_path   Path to KB.
  *
- * @return 0 on success, -1 on connection error, -2 when no DB is available.
+ * @return 0 on success, -1 on connection error, -2 when no DB is available, -3
+ * when given kb_path was NULL.
  */
 static int
 redis_new (kb_t *kb, const char *kb_path)
@@ -422,6 +423,9 @@ redis_new (kb_t *kb, const char *kb_path)
   struct kb_redis *kbr;
   int rc = 0;
 
+  if (kb_path == NULL)
+    return -3;
+
   kbr = g_malloc0 (sizeof (struct kb_redis));
   kbr->kb.kb_ops = &KBRedisOperations;
   kbr->path = g_strdup (kb_path);
@@ -466,6 +470,9 @@ redis_direct_conn (const char *kb_path, const int kb_index)
   struct kb_redis *kbr;
   redisReply *rep;
 
+  if (kb_path == NULL)
+    return NULL;
+
   kbr = g_malloc0 (sizeof (struct kb_redis));
   kbr->kb.kb_ops = &KBRedisOperations;
   kbr->path = g_strdup (kb_path);
@@ -511,6 +518,9 @@ redis_find (const char *kb_path, const char *key)
   struct kb_redis *kbr;
   unsigned int i = 1;
 
+  if (kb_path == NULL)
+    return NULL;
+
   kbr = g_malloc0 (sizeof (struct kb_redis));
   kbr->kb.kb_ops = &KBRedisOperations;
   kbr->path = g_strdup (kb_path);
@@ -629,7 +639,10 @@ redis2kbitem_single (const char *name, const redisReply *elt, int force_int)
   else
     {
       item->type = KB_TYPE_STR;
+#pragma GCC diagnostic push
+#pragma GCC diagnostic warning "-Wdeprecated-declarations"
       item->v_str = g_memdup (elt->str, elt->len + 1);
+#pragma GCC diagnostic pop
       item->len = elt->len;
     }
 
@@ -818,6 +831,9 @@ redis_push_str (kb_t kb, const char *name, const char *value)
   redisReply *rep = NULL;
   int rc = 0;
 
+  if (!value)
+    return -1;
+
   kbr = redis_kb (kb);
   rep = redis_cmd (kbr, "LPUSH %s %s", name, value);
   if (!rep || rep->type == REDIS_REPLY_ERROR)
